@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "eldoc-box" "1.14.1"
+(define-package "eldoc-box" "20250920.125"
   "Display documentation in childframe."
   '((emacs "27.1"))
   :url "https://github.com/casouri/eldoc-box"
-  :commit "8c5104f06700b774b8af76d77a440e334fbc03e9"
-  :revdesc "8c5104f06700"
+  :commit "fead2cef661790417267e5498d4d14806e020f99"
+  :revdesc "fead2cef6617"
   :authors '(("Yuan Fu" . "casouri@gmail.com"))
   :maintainers '(("Yuan Fu" . "casouri@gmail.com")))
