@@ -2,8 +2,8 @@
 
 ;; Copyright (C) 2018 Yuan Fu
 
-;; Package-Version: 1.14.1
-;; Package-Revision: 8c5104f06700
+;; Package-Version: 20250920.125
+;; Package-Revision: fead2cef6617
 
 ;; Author: Yuan Fu <casouri@gmail.com>
 ;; URL: https://github.com/casouri/eldoc-box
@@ -190,6 +190,12 @@ If non-nil, in ‘eldoc-box-hover-at-point-mode’, the childframe is
 displayed above point rather than below it."
   :type 'boolean)
 
+(defcustom eldoc-box-mouse-mode-idle-delay 0.3
+  "Seconds to wait before showing doc at mouse point.
+
+This only applies to ‘eldoc-box-mouse-mode’."
+  :type 'number)
+
 (defvar eldoc-box-position-function #'eldoc-box--default-upper-corner-position-function
   "Eldoc-box uses this function to set childframe's position.
 
@@ -303,6 +309,23 @@ Intended for internal use."
     (delete-frame eldoc-box--frame)
     (setq eldoc-box--frame nil)))
 
+(defun eldoc-box--frame-visible-p ()
+  "Returns t when the childframe is visible."
+  (and
+   eldoc-box--frame
+   (frame-visible-p eldoc-box--frame)))
+
+(defun eldoc-box--pos-in-frame-p (pos)
+  "Returns t if pixel POS (x . y) lies within the childframe."
+  (let*
+	  ((box eldoc-box--frame)
+	   (box-pos (frame-position box))
+	   (box-x (car box-pos))
+	   (box-y (cdr box-pos)))
+	(and
+	 (<= box-x (car pos) (+ box-x (frame-pixel-width box)))
+	 (<= box-y (cdr pos) (+ box-y (frame-pixel-height box))))))
+
 ;;;;; Commands
 
 (defun eldoc-box-scroll-up (arg)
@@ -377,6 +400,21 @@ For DOCS, see ‘eldoc-display-functions’."
 (defvar eldoc-box--buffer " *eldoc-box*"
   "The buffer used to display documentation.")
 
+(defvar eldoc-box--mouse-timer nil
+  "The idle timer to trigger display on mouse hover.")
+
+(defvar eldoc-box--mouse-location nil
+  "The mouse location to display documentation at.
+The value should be a cons (WINDOW . POS), where POS is buffer position.")
+
+(defvar eldoc-box--old-track-mouse nil
+  "The original value of `track-mouse'.
+
+Value before enabling `eldoc-box--mouse-support-mode'")
+
+(defvar-local eldoc-box--old-eldoc-mode nil
+  "The original value of `eldoc-mode' before enabling `eldoc-box-mouse-mode'")
+
 ;;;;; Function
 
 ;; Please compiler.
@@ -494,12 +532,12 @@ WINDOW nil means use selected window."
                 ;; normal, just return y - height
                 (- y height))
             (if (< (- (frame-inner-height) height) y)
-              ;; space under the pos is not enough
-              ;; put above
-              (max 0 (- y height))
-            ;; normal, just return y + em
-            (+ y em)))
-	  )))
+                ;; space under the pos is not enough
+                ;; put above
+                (max 0 (- y height))
+              ;; normal, just return y + em
+              (+ y em)))
+	      )))
 
 (defun eldoc-box--default-at-point-position-function (width height)
   "Set `eldoc-box-position-function' to this function.
@@ -643,7 +681,8 @@ Checkout `lsp-ui-doc--make-frame', `lsp-ui-doc--move-frame'."
            (or (and (not eldoc-last-message) ; 1
                     (not (eq (point) eldoc-box--last-point)) ; 2
                     (not (eq (current-buffer) (get-buffer eldoc-box--buffer)))) ; 3
-               (not (or eldoc-box-hover-mode eldoc-box-hover-at-point-mode)))) ; 4
+               (not (or eldoc-box-hover-mode eldoc-box-hover-at-point-mode))) ; 4
+		   (not (eldoc-box--mouse-still-hovering-p))) ; 5
       ;; 1. Obviously, last-message nil means we are not on a valid symbol anymore.
       ;; 2. Or are we? If you scroll the childframe with mouse wheel
       ;; `eldoc-pre-command-refresh-echo-area' will set `eldoc-last-message' to nil.
@@ -656,7 +695,10 @@ Checkout `lsp-ui-doc--make-frame', `lsp-ui-doc--move-frame'."
       ;; 4. Sometimes you switched buffer when childframe is on.
       ;; it wouldn't go away unless you goes back and let eldoc shut it off.
       ;; So if we are not in `eldoc-box-hover-mode', clear childframe
-      (eldoc-box-quit-frame)
+	  ;; 5. Do not clean up while the mouse is still hovering.
+      (progn
+		(setq eldoc-box--mouse-location nil)
+		(eldoc-box-quit-frame))
     ;; so you didn't clear the doc frame this time, and the last timer has ran out
     ;; setup another one to make sure the doc frame is cleared
     ;; once the condition above it met
@@ -758,6 +800,8 @@ The default position of childframe is upper corner."
   (if eldoc-box-hover-mode
       (progn (when eldoc-box-hover-at-point-mode
                (eldoc-box-hover-at-point-mode -1))
+			 (when eldoc-box-mouse-mode
+			   (eldoc-box-mouse-mode -1))
              (eldoc-box--enable))
     (eldoc-box--disable)))
 
@@ -769,6 +813,8 @@ You can use \\[keyboard-quit] to hide the doc."
   (if eldoc-box-hover-at-point-mode
       (progn (when eldoc-box-hover-mode
                (eldoc-box-hover-mode -1))
+			 (when eldoc-box-mouse-mode
+			   (eldoc-box-mouse-mode -1))
              (setq-local eldoc-box-position-function
                          eldoc-box-at-point-position-function)
              (setq-local  eldoc-box-clear-with-C-g t)
@@ -781,6 +827,127 @@ You can use \\[keyboard-quit] to hide the doc."
     (kill-local-variable 'eldoc-box-position-function)
     (kill-local-variable 'eldoc-box-clear-with-C-g)))
 
+;;;###autoload
+(define-minor-mode eldoc-box--mouse-support-mode
+  "Global functionality required for `eldoc-box-mouse-mode'."
+  :lighter eldoc-box-lighter
+  :global t
+  (if eldoc-box--mouse-support-mode
+	  (progn
+		(setq eldoc-box--old-track-mouse track-mouse)
+		(unless track-mouse
+		  (setq track-mouse t))
+		(unless eldoc-box--mouse-timer
+		  (setq eldoc-box--mouse-timer
+				(run-with-idle-timer eldoc-box-mouse-mode-idle-delay
+                                     t  'eldoc-box--mouse-on-idle))))
+	(cancel-timer eldoc-box--mouse-timer)
+	(setq eldoc-box--mouse-timer nil)
+	(setq eldoc-box--mouse-location nil)
+	(setq track-mouse eldoc-box--old-track-mouse)))
+
+(define-minor-mode eldoc-box-mouse-mode
+  "Display hover documentations on mouse hover in a childframe.
+The position of childframe is at mouse position."
+  :lighter eldoc-box-lighter
+  (if eldoc-box-mouse-mode
+	  (eldoc-box--mouse-enable)
+	(eldoc-box--mouse-disable)))
+
+;;;; Mouse mode
+
+(defun eldoc-box--mouse-on-idle ()
+  "Triggers documetation display for mouse-pointed text.
+
+But only if mouse is currently hovering over a valid
+`eldoc-box-mouse-mode' position. And only triggers if there is not
+already a previous documentation box active."
+  (when (not (eldoc-box--frame-visible-p))
+	(when-let*
+		((mouse-pos (mouse-pixel-position))
+		 (frame (car mouse-pos))
+		 (xy (cdr mouse-pos))
+		 (info (posn-at-x-y (car xy) (cdr xy) frame))
+		 (window (nth 0 info))
+		 (pos (nth 5 info))
+		 (buffer (window-buffer window)))
+	  (when (buffer-local-value 'eldoc-box-mouse-mode buffer)
+		(setq eldoc-box--mouse-location (cons window pos))
+        (with-current-buffer buffer
+          (save-excursion
+		    (goto-char pos)
+            ;; We can’t override the display function here like we
+            ;; do in ‘eldoc-box-help-at-point’, because eldoc doc
+            ;; function might by async.
+		    (when (not (eolp)) (eldoc-print-current-symbol-info))))))))
+
+(defun eldoc-box--mouse-still-hovering-p ()
+  "Returns non-nil if mouse is still hovering at the same position.
+
+This is used for deciding whether to keep showing the doc childframe."
+  (let*
+	  ((mouse-pos (mouse-pixel-position))
+	   (frame (car mouse-pos))
+	   (xy (cdr mouse-pos))
+	   (info (posn-at-x-y (car xy) (cdr xy) frame))
+	   (window (nth 0 info))
+	   (pos (nth 5 info))
+	   (buffer (window-buffer window)))
+	(cond
+     ;; Keep the frame if mouse pointer is in it.
+	 ((eldoc-box--pos-in-frame-p xy))
+     ;; Keep the frame if mouse still points to the same position.
+	 ((buffer-local-value 'eldoc-box-mouse-mode buffer)
+	  (eq eldoc-box--last-point pos)))))
+
+(defun eldoc-box--mouse-enable ()
+  "Enable eldoc-box-mouse.
+Intended for internal use."
+  (unless eldoc-box--mouse-support-mode
+	(eldoc-box--mouse-support-mode 1))
+  (when eldoc-mode
+	(setq-local eldoc-box--old-eldoc-mode t)
+	(eldoc-mode -1))
+  (when eldoc-box-hover-mode
+	(eldoc-box-hover-mode -1))
+  (when eldoc-box-hover-at-point-mode
+	(eldoc-box-hover-at-point-mode -1))
+  (setq-local eldoc-box-position-function eldoc-box-at-point-position-function)
+  (eldoc-box--enable)
+  (setq-local eldoc-display-functions
+              (cons 'eldoc-box--mouse-display-function
+                    (remq 'eldoc-box--eldoc-display-function
+                          eldoc-display-functions))))
+
+(defun eldoc-box--mouse-disable ()
+  "Disable eldoc-box-mouse.
+Intended for internal use."
+  (setq-local eldoc-display-functions
+              (remq 'eldoc-box--mouse-display-function
+                    eldoc-display-functions))
+  (eldoc-box--disable)
+  (kill-local-variable 'eldoc-box-position-function)
+  (when eldoc-box--old-eldoc-mode
+	(eldoc-mode 1)
+	(kill-local-variable 'eldoc-box--old-eldoc-mode)))
+
+(defun eldoc-box--mouse-display-function (docs interactive)
+  "Display DOCS in childframe.
+
+For DOCS and INTERACTIVE see ‘eldoc-display-functions’. Optionally
+display the docs in echo area depending on ‘eldoc-box-only-multi-line’."
+  (let ((doc (string-trim (string-join
+                           (mapcar #'eldoc-box--compose-doc docs)
+                           eldoc-box-doc-separator))))
+	(save-window-excursion
+	  (when eldoc-box--mouse-location
+		(progn
+		  (select-window (car eldoc-box--mouse-location) t)
+		  (save-excursion
+			(goto-char (cdr eldoc-box--mouse-location))
+			(when (eldoc-box--eldoc-message-function "%s" doc)
+			  (eldoc-display-in-echo-area docs interactive))))))))
+
 ;;;; Eglot helper
 
 (make-obsolete 'eldoc-box-eglot-help-at-point 'eldoc-box-help-at-point
